<?php
/**
 * multi data view helper callback functions
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library, 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace finc\View\Helper\Root;

/**
 * multi data view helper callback functions
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Dorian Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
trait MultiDataFieldsTrait
{
    /**
     * return render details for additionals data set
     * @return callback
     */
    public function additionals($data, $options)
    {
        // Sort the data:
        $final = [];
        foreach ($data as $type => $values) {
            $final[] = [
                'label' => $values['identifier'],
                'values' => [$type => $values],
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'RecordDriverTemplate',
                    'template' => 'data-additionals.phtml',
                ],
            ];
        }
        return $final;
    }

    /**
     * return render details for otherRelationshipEntry data set
     * @return callback
     */
    public function otherRelationShipEntry($data, $options)
    {
        // Sort the data:
        $final = [];
        foreach ($data as $type => $values) {
            $final[] = [
                'label' => $values[0]['subject'],
                'values' => [$type => $values],
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'RecordDriverTemplate',
                    'template' => 'data-otherRelationshipEntry.phtml',
                ],
            ];
        }
        return $final;
    }

    public function relatedRecords($data,$options,$driver) {

        $formats = $driver->tryMethod('getFormat');
        $reject = array('Microfilm', 'Microform', 'Microfiche');
        if (empty(array_intersect($reject, $formats))) {
            $data = $driver->tryMethod(
                'getRelatedRecords',
                [$options['limit'] ?? 3]
            );
        }
        if (!empty($data['first_results'])) {
            return [[
                'label' => 'Other Editions',
                'values' => $data,
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'RecordDriverTemplate',
                    'template' => 'data-relatedRecords.phtml',
                ],
            ]];
        }
        return null;
    }

    /**
     * return render details for events data set
     * @return callback
     */
    public function events($data, $options)
    {
        // Sort the data:
        $final = [];
        foreach ($data as $eventType => $values) {
            switch ($eventType) {
                case 'production': $title = 'expression creation'; break;
                case 'publication': $title = 'Time of origin'; break;
                default: $title = $eventType;
            }
            $final[] = [
                'label' => $title,
                'values' => [$eventType => $values],
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'RecordDriverTemplate',
                    'template' => 'data-events.phtml',
                ],
            ];
        }
        return $final;
    }


    /**
     * return render details for titleUniform data set
     * @return callback
     */
    public function isbnIssns($data, $options, $driver)
    {
        // Sort the data:
        $final = [];
        foreach ($data as $type => $values) {
            $final[] = [
                'label' => $driver->tryMethod('isRDA')
                    ? 'rda_original_title'
                    : 'non_rda_original_title',
                'values' => [$type => $values],
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'RecordDriverTemplate',
                    'template' => 'data-titleUniform.phtml',
                ],
            ];
        }
        return $final;
    }

    /**
     * return render details for otherIdentifiers (MARC 024)  data set
     * @return callback
     */
    public function otherIdentifiers($data, $options, $driver)
    {
        // Sort the data:
        $final = [];
        foreach ($data as $type => $values) {
            $final[] = [
                'label' => $type,
                'values' => $values,
                'options' => [
                    'pos' => $options['pos'],
                    'renderType' => 'Simple',
                ],
            ];
        }
        return $final;
    }

}
